import {AdRecord} from "../records/ad.record";
import {AdEntity} from "../types";
import {pool} from "../utils/db";

afterAll(async () => {
    await pool.end()
})

const defaultObj = {
    name: 'Test Name',
    description: 'blablabla',
    url: 'http://megak.pl',
    price: 0,
    lat: 9,
    lon: 3,
};

test('AdRecord returns data from database for one entry.', async () => {

    const ad = await AdRecord.getOne('abc');

    expect(ad).toBeDefined();
    expect(ad.id).toBe('abc');
    expect(ad.name).toBe('test');

})

test('AdRecord returns null from database from nonexistent entry.', async () => {

    const ad = await AdRecord.getOne('---');

    expect(ad).toBeNull();

})

test('AdRecord.findAll returns array of found entries.', async () => {
    const ad = await AdRecord.findAll('');

    expect(ad).not.toEqual([]);
    expect(ad[0].id).toBeDefined();
})

test('AdRecord.findAll returns array of found entries when searching for "a".', async () => {
    const ad = await AdRecord.findAll('t');

    expect(ad).not.toEqual([]);
    expect(ad[0].id).toBeDefined();
})

test('AdRecord.findAll returns empty array when searching for something that does not exist.', async () => {
    const ad = await AdRecord.findAll('---------------------------');

    expect(ad).toEqual([]);
})

test('AdRecord.findAll returns small amount of data.', async () => {
    const ad = await AdRecord.findAll('');

    expect((ad[0] as AdEntity).price).toBeUndefined();
    expect((ad[0] as AdEntity).description).toBeUndefined();
})

test('AdRecord.insert returns new uuid.', async () => {
    const ad = new AdRecord(defaultObj);
    await ad.insert();

    expect(ad.id).toBeDefined();
    expect(typeof ad.id).toBe('string');
})


test('AdRecord.insert inserts data to database.', async () => {
    const ad = new AdRecord(defaultObj);
    await ad.insert();

    const foundAd = await AdRecord.getOne(ad.id);

    expect(foundAd).toBeDefined()
    expect(foundAd).not.toBeNull()
    expect(foundAd.id).toBe(ad.id)
})